{% include "header.html" %}
{% if params %}
  {% set urlq = url + '?' + params + '&' %}
  {% else %}
  {% set urlq = url + '?' %}
{% endif %}

<nav aria-label="breadcrumb">
  <ol class="breadcrumb bg-light">
    {% for crumb in crumbs %}
      {% if not loop.last %}
    <li class="breadcrumb-item"><a href="{{ crumb.url }}/">{{ crumb.part }}</a></li>
      {% else %}<li class="breadcrumb-item active" aria-current="page">{{ crumb.part }}</li>
      {% endif %}
    {% endfor %}

    <li class="ml-auto json-link"><a target="_blank" href="{{ urlq }}f=json">JSON</a></li>
  </ol>
</nav>

<h1>{{ response.title }}</h1>
<p>
  {{ response.description }}
</p>

<pre>
  ______   __     ______   __     __         ______     ______
/\__  _\ /\ \   /\__  _\ /\ \   /\ \       /\  ___\   /\  == \
\/_/\ \/ \ \ \  \/_/\ \/ \ \ \  \ \ \____  \ \  __\   \ \  __<
    \ \_\  \ \_\    \ \_\  \ \_\  \ \_____\  \ \_____\  \ \_\ \_\
    \/_/   \/_/     \/_/   \/_/   \/_____/   \/_____/   \/_/ /_/

  </pre>

<h2>Links</h2>
<ul>
{% for link in response.links %}
  <li> <a href="{{ link.href }}">{{ link.title or link.rel }}</a></li>
{% endfor %}
</ul>

{% include "footer.html" %}
